summaryrefslogtreecommitdiffstats
path: root/Source/cmMSProjectGenerator.h
diff options
context:
space:
mode:
authorBill Hoffman <bill.hoffman@kitware.com>2001-06-06 17:48:13 (GMT)
committerBill Hoffman <bill.hoffman@kitware.com>2001-06-06 17:48:13 (GMT)
commit38a164d254a557bb46134c049bd809a487e325b4 (patch)
tree00e6972d5d90f61cb98b20e2f218fc3ebf2d9c51 /Source/cmMSProjectGenerator.h
parentb31fcf1cacf720bcd02ee9ea657c2a26be54f064 (diff)
downloadCMake-38a164d254a557bb46134c049bd809a487e325b4.zip
CMake-38a164d254a557bb46134c049bd809a487e325b4.tar.gz
CMake-38a164d254a557bb46134c049bd809a487e325b4.tar.bz2
ENH: rename DSWMakefile and DSPMakefile to DSWWriter and DSPWriter
Diffstat (limited to 'Source/cmMSProjectGenerator.h')
-rw-r--r--Source/cmMSProjectGenerator.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/Source/cmMSProjectGenerator.h b/Source/cmMSProjectGenerator.h
index 07f7a50..08d8678 100644
--- a/Source/cmMSProjectGenerator.h
+++ b/Source/cmMSProjectGenerator.h
@@ -44,8 +44,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#include "cmStandardIncludes.h"
#include "cmMakefileGenerator.h"
-class cmDSPMakefile;
-class cmDSWMakefile;
+class cmDSPWriter;
+class cmDSWWriter;
/** \class cmMSProjectGenerator
* \brief Write a Microsoft Visual C++ DSP (project) file.
@@ -87,16 +87,16 @@ public:
void BuildDSWOn() {m_BuildDSW = true;}
/**
* Retrieve a pointer to a cmDSWMakefile instance.
*/
- cmDSWMakefile* GetDSWMakefile()
- {return m_DSWMakefile;}
+ cmDSWWriter* GetDSWWriter()
+ {return m_DSWWriter;}
/**
* Retrieve a pointer to a cmDSPMakefile instance.
*/
- cmDSPMakefile* GetDSPMakefile()
- {return m_DSPMakefile;}
+ cmDSPWriter* GetDSPWriter()
+ {return m_DSPWriter;}
/**
* Try to determine system infomation such as shared library
@@ -105,8 +105,8 @@ public:
virtual void ComputeSystemInfo();
private:
- cmDSWMakefile* m_DSWMakefile;
- cmDSPMakefile* m_DSPMakefile;
+ cmDSWWriter* m_DSWWriter;
+ cmDSPWriter* m_DSPWriter;
bool m_BuildDSW;
};
@@ -87,16 +87,16 @@ public:
void BuildDSWOn() {m_BuildDSW = true;}
/**
- * Retrieve a pointer to a cmDSWMakefile instance.
+ * Retrieve a pointer to a cmDSWWriter instance.
*/
@@ -87,16 +87,16 @@ public:
/**
- * Retrieve a pointer to a cmDSPMakefile instance.
+ * Retrieve a pointer to a cmDSPWriter instance.
*/